@@ -948,6 +948,7 @@ def build_ospf(anm):
         return
 
     g_ospf.add_nodes_from(g_in.nodes("is_router", igp = "ospf"), retain=['asn'])
+    g_ospf.add_nodes_from(g_in.nodes("is_server", igp = "ospf"), retain=['asn'])
     g_ospf.add_nodes_from(g_in.nodes("is_switch"), retain=['asn'])
     g_ospf.add_edges_from(g_in.edges(), retain=['edge_id'])
 
@@ -1083,6 +1084,7 @@ def build_isis(anm):
         return
     g_ipv4 = anm['ipv4']
     g_isis.add_nodes_from(g_in.nodes("is_router", igp = "isis"), retain=['asn'])
+    g_isis.add_nodes_from(g_in.nodes("is_server", igp = "isis"), retain=['asn'])
     g_isis.add_nodes_from(g_in.nodes("is_switch"), retain=['asn'])
     g_isis.add_edges_from(g_in.edges(), retain=['edge_id'])
 # Merge and explode switches
